# `parsomics-metapackage`

A metapackage for the parsomics project. It includes:

- parsomics-cli
- parsomics-core
- parsomics-api-server
- parsomics-plugin-clean
- parsomics-plugin-dbcan
- parsomics-plugin-interpro
- parsomics-plugin-proteinfer

## License

This work is licensed under the terms of the GPL-3.0.

## Copyright

© 2025 Brazilian Center for Research in Energy and Materials (CNPEM).
